@@ -21,6 +21,8 @@
 #include "config.h"
 #endif
 
+#include <algorithm>
+
 #include <stdlib.h>
 #include <unistd.h>
 #include <wait.h>
@@ -34,6 +36,7 @@
 #include <kmessagebox.h>
 #include <kaboutapplication.h>
 #include <kpopupmenu.h>
+#include <kprocess.h>
 
 #include "statusbutton.h"
 #include "light.h"
@@ -55,29 +58,12 @@ extern "C" {
 
 extern char **environ;
 
-static int system_nowait(const char *command)
+static bool system_nowait(const char *command)
 {
-  if (command == 0)
-    return 1;
-  
-  /* go in "daemon mode" */
-  pid_t pid = fork();
-  if (pid < 0) return -1;	/* fork failed */
-  if (pid == 0) {    		/* we are the child */
-    pid_t cpid = fork();	/* fork the "daemon" */
-    if (cpid < 0) exit(-1);	/* fork failed */
-    if (cpid > 0) exit(0);	/* exit parent, to satify waiting process */
-    setsid();			/* found new processgroup */
-    const char * argv[4];
-    argv[0] = "sh";
-    argv[1] = "-c";
-    argv[2] = command;
-    argv[3] = 0;
-    execve("/bin/sh", (char *const *)argv, environ);
-    exit(127);
-  }
-  waitpid(pid, 0, 0);
-  return 0;
+  KProcess proc;
+  proc.setUseShell(true);
+  proc << command;
+  return proc.start(KProcess::DontCare);
 }
 
 KModemLightsApplet::KModemLightsApplet(const QString& configFile, Type type, 
@@ -151,7 +137,7 @@ KModemLightsApplet::~KModemLightsApplet()
 int KModemLightsApplet::widthForHeight(int height) const
 {
   // two-row-layout or single-row-layout
-  int widgetheight = height >= 42 ? (height-1)/4 : height/2;
+  int widgetheight = height >= 42 ? height/4 : height/2;
   
   // button
   int b = button->sizeHint().width();
@@ -164,10 +150,11 @@ int KModemLightsApplet::widthForHeight(int height) const
   font.setPixelSize(widgetheight);
   // guess the maximum size by calulate the size of a string set to 
   // 4 digits and 2 characters (b,m,' or ")
-  int w2 = (QFontMetrics(font).width("88m88m"));
+  // +1 necessary for unknown reason ?!
+  int w2 = (QFontMetrics(font).width("88m88m"))+1;
 
   if (height >= 42) // two-row-layout 
-    return b + page->spacing() + (w1>w2 ? w1 : w2);
+    return b + page->spacing() + std::max(w1,w2);
   else  // single-row-layout
     return b + page->spacing() + w1 + infoPart->spacing() + w2;
 }
