@@ -32,8 +32,7 @@ class Light : public QWidget
 
   Light(const QColor &cOn, const QColor &cOff, QWidget *parent, const char *name = 0);
 
-  virtual QSize sizeHint () const;
-  virtual QSize minimumSizeHint () const;
+  virtual QSize sizeHint () const { return on.size(); }
 
   void setStatus(bool s);
   bool status() const { return lightStatus; };
